<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.1">
<context>
    <name>App.About</name>
    <message>
        <source>System Monitor</source>
        <translation>Monitor systémových prostředků</translation>
    </message>
    <message>
        <source>System Monitor is a tool to monitor realtime system load, view and control processes and services running on your system.</source>
        <translation>Monitor systémových prostředků je nástroj pro sledování vytížení systému v reálném čase, zobrazování a řízení procesů a služeb spuštěných ve vašem systému.</translation>
    </message>
</context>
<context>
    <name>BaseDetailViewWidget</name>
    <message>
        <source>Hide details</source>
        <translation>Skrýt podrobnosti</translation>
    </message>
    <message>
        <source>Overall utilization</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Individual utilization</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BlockDevItemWidget</name>
    <message>
        <source>Read</source>
        <translation>Čtení</translation>
    </message>
    <message>
        <source>Write</source>
        <translation>Zápis</translation>
    </message>
</context>
<context>
    <name>CPUDetailGrapTableItem</name>
    <message>
        <source>60 seconds</source>
        <translation>60 sekund</translation>
    </message>
</context>
<context>
    <name>CPUInfoModel</name>
    <message>
        <source>%1 days %2 hours %3 minutes</source>
        <translation>%1 dnů %2 hodin %3 minut</translation>
    </message>
</context>
<context>
    <name>CPUSummaryTableModel</name>
    <message>
        <source>Utilization</source>
        <translation>Vytížení</translation>
    </message>
    <message>
        <source>Current frequency</source>
        <translation>Stávající frekvence</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>Frekvence</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Výrobce</translation>
    </message>
    <message>
        <source>Sockets</source>
        <translation>Patice</translation>
    </message>
    <message>
        <source>Logical processors</source>
        <translation>Logických procesorů</translation>
    </message>
    <message>
        <source>Virtualization</source>
        <translation>Virtualizace</translation>
    </message>
    <message>
        <source>L1i cache</source>
        <translation>Mezipaměť 1. úrovně (instrukční)</translation>
    </message>
    <message>
        <source>L1d cache</source>
        <translation>Mezipaměť 1. úrovně (datová)</translation>
    </message>
    <message>
        <source>L2 cache</source>
        <translation>Mezipaměť 2. úrovně</translation>
    </message>
    <message>
        <source>L3 cache</source>
        <translation>Mezipaměť 3. úrovně</translation>
    </message>
    <message>
        <source>Load average</source>
        <translation>Průměrné vytížení</translation>
    </message>
    <message>
        <source>File descriptors</source>
        <translation>Popisovače souborů</translation>
    </message>
    <message>
        <source>Processes</source>
        <translation>Procesy</translation>
    </message>
    <message>
        <source>Threads</source>
        <translation>Vlákna</translation>
    </message>
    <message>
        <source>Host name</source>
        <translation>Název stroje</translation>
    </message>
    <message>
        <source>OS type</source>
        <translation>Typ operačního systému</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Verze</translation>
    </message>
    <message>
        <source>Up time</source>
        <translation>Doba chodu od minulého zapnutí</translation>
    </message>
</context>
<context>
    <name>ChartViewWidget</name>
    <message>
        <source>60 seconds</source>
        <translation>60 sekund</translation>
    </message>
</context>
<context>
    <name>Common.Search</name>
    <message>
        <source>No search results</source>
        <translation>Nic nenalezeno</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>Podrobnosti</translation>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>Podrobnosti</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Active.State</name>
    <message>
        <source>active</source>
        <translation>aktivní</translation>
    </message>
    <message>
        <source>reloading</source>
        <translation>znovu se načítá</translation>
    </message>
    <message>
        <source>inactive</source>
        <translation>neaktivní</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>selhalo</translation>
    </message>
    <message>
        <source>activating</source>
        <translation>zapínání</translation>
    </message>
    <message>
        <source>deactivating</source>
        <translation>vypínání</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Load.State</name>
    <message>
        <source>stub</source>
        <translation>stub</translation>
    </message>
    <message>
        <source>not-found</source>
        <translation>nenalezeno</translation>
    </message>
    <message>
        <source>bad-setting</source>
        <translation>chybné nastavení</translation>
    </message>
    <message>
        <source>error</source>
        <translation>chyba</translation>
    </message>
    <message>
        <source>merged</source>
        <translation>sloučeno</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>maskováno</translation>
    </message>
    <message>
        <source>loaded</source>
        <translation>načteno</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Startup.Mode</name>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automaticky</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ručně</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.State</name>
    <message>
        <source>enabled</source>
        <translation>povoleno</translation>
    </message>
    <message>
        <source>disabled</source>
        <translation>zakázáno</translation>
    </message>
    <message>
        <source>static</source>
        <translation>statické</translation>
    </message>
    <message>
        <source>transient</source>
        <translation>přechodné</translation>
    </message>
    <message>
        <source>indirect</source>
        <translation>nepřímé</translation>
    </message>
    <message>
        <source>enabled-runtime</source>
        <translation>enabled-runtime</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>maskováno</translation>
    </message>
    <message>
        <source>generated</source>
        <translation>vytvořeno</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Sub.State</name>
    <message>
        <source>dead</source>
        <translation>neaktivní</translation>
    </message>
    <message>
        <source>start-pre</source>
        <translation>spustit-před</translation>
    </message>
    <message>
        <source>start</source>
        <translation>spustit</translation>
    </message>
    <message>
        <source>start-post</source>
        <translation>spustit-po</translation>
    </message>
    <message>
        <source>running</source>
        <translation>spuštěné</translation>
    </message>
    <message>
        <source>exited</source>
        <translation>ukončeno</translation>
    </message>
    <message>
        <source>reload</source>
        <translation>načíst znovu</translation>
    </message>
    <message>
        <source>stop</source>
        <translation>zastavit</translation>
    </message>
    <message>
        <source>stop-watchdog</source>
        <translation>stop-watchdog</translation>
    </message>
    <message>
        <source>stop-sigterm</source>
        <translation>stop-sigterm</translation>
    </message>
    <message>
        <source>stop-sigkill</source>
        <translation>stop-sigkill</translation>
    </message>
    <message>
        <source>stop-post</source>
        <translation>stop-post</translation>
    </message>
    <message>
        <source>final-sigterm</source>
        <translation>final-sigterm</translation>
    </message>
    <message>
        <source>final-sigkill</source>
        <translation>final-sigkill</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>nezdařilo se</translation>
    </message>
    <message>
        <source>auto-restart</source>
        <translation>automatický restart</translation>
    </message>
</context>
<context>
    <name>DeailTableModel</name>
    <message>
        <source>Used</source>
        <translation>Využito</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>K dispozici</translation>
    </message>
    <message>
        <source>Shared</source>
        <translation>Sdíleno</translation>
    </message>
    <message>
        <source>Cached</source>
        <translation>V mezipaměti</translation>
    </message>
    <message>
        <source>Buffers</source>
        <translation>Vyrovnávací paměti</translation>
    </message>
    <message>
        <source>Cached swap</source>
        <translation>Odkládací prostor v mezipaměti</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktivita</translation>
    </message>
    <message>
        <source>Inactive</source>
        <translation>Neaktivní</translation>
    </message>
    <message>
        <source>Dirty</source>
        <translation>„Špinavé</translation>
    </message>
    <message>
        <source>Mapped</source>
        <translation>Mapováno</translation>
    </message>
    <message>
        <source>Total swap</source>
        <translation>Celkem mezipaměti</translation>
    </message>
    <message>
        <source>Free swap</source>
        <translation>Volný odkládací prostor</translation>
    </message>
    <message>
        <source>Slab</source>
        <translation>Slab</translation>
    </message>
</context>
<context>
    <name>DeailTableModelBlock</name>
    <message>
        <source>Model</source>
        <translation>Model</translation>
    </message>
    <message>
        <source>Read speed</source>
        <translation>Rychlost čtení</translation>
    </message>
    <message>
        <source>Write speed</source>
        <translation>Rychlost zapisování</translation>
    </message>
    <message>
        <source>Capacity</source>
        <translation>Kapacita</translation>
    </message>
    <message>
        <source>Sectors read</source>
        <translation>Načteno sektorů</translation>
    </message>
    <message>
        <source>Reads/s</source>
        <translation>Čtení/s</translation>
    </message>
    <message>
        <source>Sectors read/s</source>
        <translation>Čtení sektorů / sek</translation>
    </message>
    <message>
        <source>Reads merged/s</source>
        <translation>Sloučených čtení / sek</translation>
    </message>
    <message>
        <source>Sectors written</source>
        <translation>Zapsáno sektorů</translation>
    </message>
    <message>
        <source>Writes completed </source>
        <translation>Dokončeno zápisů</translation>
    </message>
    <message>
        <source>Writes merged</source>
        <translation>Sloučeno zápisů</translation>
    </message>
    <message>
        <source>Writes/s</source>
        <translation>Zápisů/s</translation>
    </message>
    <message>
        <source>Sectors written/s</source>
        <translation>Zapsáno sektorů / sek</translation>
    </message>
    <message>
        <source>Writes merged/s</source>
        <translation>Sloučeno zápisů / sek</translation>
    </message>
</context>
<context>
    <name>Error.Dialog</name>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Help.Shortcut.System</name>
    <message>
        <source>System</source>
        <translation>Systém</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Zobrazit klávesové zkratky</translation>
    </message>
</context>
<context>
    <name>Kill.Process.Dialog</name>
    <message>
        <source>Ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Ukončení tohoto procesu může vést ke ztrátě dat.
Opravdu chcete pokračovat?</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>Ukončit proces</translation>
    </message>
    <message>
        <source>Force ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Vynucení ukončení tohoto procesu může vést ke ztrátě dat.
Opravdu chcete pokračovat?</translation>
    </message>
    <message>
        <source>Force ending this application may cause data loss.
Are you sure you want to continue?</source>
        <translation>Vynucení ukončení této aplikace může vést ke ztrátě dat.
Opravdu chcete pokračovat?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Storno</translation>
    </message>
    <message>
        <source>Force End</source>
        <comment>button</comment>
        <translation>Vynutit ukončení</translation>
    </message>
    <message>
        <source>End</source>
        <comment>button</comment>
        <translation>Ukončit</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
</context>
<context>
    <name>MemStatViewWidget</name>
    <message>
        <source>Size</source>
        <translation>Velikost</translation>
    </message>
</context>
<context>
    <name>NetInfoDetailItemDelegate</name>
    <message>
        <source>IP address:</source>
        <translation>IP adresa:</translation>
    </message>
    <message>
        <source>Netmask:</source>
        <translation>Maska sítě:</translation>
    </message>
    <message>
        <source>Broadcast:</source>
        <translation>Všesměrové vysílání:</translation>
    </message>
    <message>
        <source>Prefixlen:</source>
        <translation>Délka předpony:</translation>
    </message>
    <message>
        <source>Scope:</source>
        <translation>Rozsah:</translation>
    </message>
</context>
<context>
    <name>NetInfoModel</name>
    <message>
        <source>Connection type</source>
        <translation>Typ připojen</translation>
    </message>
    <message>
        <source>ESSID</source>
        <translation>ESSID</translation>
    </message>
    <message>
        <source>Link quality</source>
        <translation>Kvalita linky</translation>
    </message>
    <message>
        <source>Signal strength</source>
        <translation>Síla signálu</translation>
    </message>
    <message>
        <source>Noise level</source>
        <translation>Úroveň šumu</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>Bandwidth</source>
        <translation>Šíře pásma</translation>
    </message>
    <message>
        <source>RX packets</source>
        <translation>Přijato paketů</translation>
    </message>
    <message>
        <source>RX bytes</source>
        <translation>Přijato bajtů</translation>
    </message>
    <message>
        <source>RX errors</source>
        <translation>Chyb příjmu</translation>
    </message>
    <message>
        <source>RX dropped</source>
        <translation>Příjem zahozeno</translation>
    </message>
    <message>
        <source>RX overruns</source>
        <translation>Přij. přetečení</translation>
    </message>
    <message>
        <source>RX frame</source>
        <translation>Přij. rámec</translation>
    </message>
    <message>
        <source>TX packets</source>
        <translation>Odesl. paketů</translation>
    </message>
    <message>
        <source>TX bytes</source>
        <translation>Odesl. bajtů</translation>
    </message>
    <message>
        <source>TX errors</source>
        <translation>Chyb odesíl.</translation>
    </message>
    <message>
        <source>TX overruns</source>
        <translation>Odesl. přetečení</translation>
    </message>
    <message>
        <source>TX carrier</source>
        <translation>Nosná odesíl.</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>TX dropped</source>
        <translation>Zahozeno odeslání</translation>
    </message>
</context>
<context>
    <name>Process.Attributes.Dialog</name>
    <message>
        <source>Command line</source>
        <translation>Příkazový řádek</translation>
    </message>
    <message>
        <source>Start time</source>
        <translation>Okamžik spuštění</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Název</translation>
    </message>
</context>
<context>
    <name>Process.Choose.Window.Dialog</name>
    <message>
        <source>Click the application you want to end</source>
        <translation>Klepněte na program, který chcete ukončit</translation>
    </message>
</context>
<context>
    <name>Process.Graph.Title</name>
    <message>
        <source>Memory</source>
        <translation>Operační paměť </translation>
    </message>
    <message>
        <source>Receive</source>
        <translation>Obdržet</translation>
    </message>
</context>
<context>
    <name>Process.Graph.View</name>
    <message>
        <source>CPU</source>
        <translation>Procesor</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Čtení z úložiště</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Zápis na úložiště</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Operační paměť </translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Odkládací prostor (swap) </translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Nepovoleno</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Příjem</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Odesílání</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Síť</translation>
    </message>
    <message>
        <source>Total Received</source>
        <translation>Celkem přijato</translation>
    </message>
    <message>
        <source>Total Sent</source>
        <translation>Celkem odesl.</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Odesláno</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Disky</translation>
    </message>
</context>
<context>
    <name>Process.Priority</name>
    <message>
        <source>Very high</source>
        <translation>Velmi vysoká</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Vysoká</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normální</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Nízká</translation>
    </message>
    <message>
        <source>Very low</source>
        <translation>Velmi nízká</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Vlastní</translation>
    </message>
    <message>
        <source>Invalid</source>
        <translation>Neplatná</translation>
    </message>
    <message>
        <source>PID: %1, Error: [%2] %3</source>
        <translation>PID: %1, chyba: [%2] %3</translation>
    </message>
    <message>
        <source>Failed to change process priority</source>
        <translation>Nepodařilo se změnit prioritu procesu</translation>
    </message>
</context>
<context>
    <name>Process.Show.Mode</name>
    <message>
        <source>Applications</source>
        <translation>Aplikace</translation>
    </message>
    <message>
        <source>My processes</source>
        <translation>Moje procesy</translation>
    </message>
    <message>
        <source>All processes</source>
        <translation>Všechny procesy</translation>
    </message>
</context>
<context>
    <name>Process.Loading</name>
    <message>
        <source>Loading</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Process.Signal</name>
    <message>
        <source>Failed to pause process</source>
        <translation>Proces se nepodařilo pozastavit</translation>
    </message>
    <message>
        <source>Failed to resume process</source>
        <translation>Nepodařilo se obnovit běh procesu</translation>
    </message>
    <message>
        <source>Failed to kill process</source>
        <translation>Nepodařilo se vynutit ukončení procesu</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Neznámá chyba</translation>
    </message>
    <message>
        <source>Failed in sending signal to process</source>
        <translation>Nepodařilo se poslat procesu signál</translation>
    </message>
    <message>
        <source>Failed to end process</source>
        <translation>Proces se nepodařilo ukončit</translation>
    </message>
</context>
<context>
    <name>Process.Summary</name>
    <message>
        <source>(%1 applications and %2 processes are running)</source>
        <translation>(jsou spuštěné %1 aplikace a %2 procesů)</translation>
    </message>
</context>
<context>
    <name>Process.Table</name>
    <message>
        <source>No response</source>
        <translation>Žádná odpověď</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Uspáno</translation>
    </message>
    <message>
        <source>Tray</source>
        <translation>Panel</translation>
    </message>
</context>
<context>
    <name>Process.Table.Context.Menu</name>
    <message>
        <source>View command location</source>
        <translation>Zobrazit umístění příkazu</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Vlastnosti</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>Ukončit proces</translation>
    </message>
    <message>
        <source>Resume process</source>
        <translation>Obnovit proces</translation>
    </message>
    <message>
        <source>Kill process</source>
        <translation>Vynutit ukončení procesu</translation>
    </message>
    <message>
        <source>Change priority</source>
        <translation>Změnit prioritu</translation>
    </message>
    <message>
        <source>Suspend process</source>
        <translation>Pozastavit proces</translation>
    </message>
</context>
<context>
    <name>Process.Table.Custom.Priority.Dialog</name>
    <message>
        <source>Custom Priority</source>
        <translation>Uživatelsky určená priorita</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Storno</translation>
    </message>
    <message>
        <source>Change</source>
        <comment>button</comment>
        <translation>Změnit</translation>
    </message>
</context>
<context>
    <name>Process.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <source>CPU</source>
        <translation>Procesor</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Paměť</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Zápis na úložiště</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Čtení z úložiště</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Příjem</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Odesílání</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>Identif. procesu</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Uživatel</translation>
    </message>
    <message>
        <source>Nice</source>
        <translation>Priorita (nice)</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Priorita</translation>
    </message>
    <message>
        <source>Shared memory</source>
        <translation>Sdílená paměť</translation>
    </message>
    <message>
        <source>Virtual memory</source>
        <translation>Virtuální paměť</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Not support</source>
        <translation>Nepodporováno</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>System Protection</source>
        <translation>Ochrana systému</translation>
    </message>
    <message>
        <source>Show warnings when the usage exceeds the thresholds</source>
        <translation>Zobrazit varování, pokud využití přesáhne nastavenou hranici</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Upozornění</translation>
    </message>
    <message>
        <source>CPU warning threshold (%)</source>
        <translation>Práh varování ohledně procesoru (%)</translation>
    </message>
    <message>
        <source>Memory warning threshold (%)</source>
        <translation>Práh varování ohledně paměti (%)</translation>
    </message>
    <message>
        <source>Warning interval (min)</source>
        <translation>Interval varování (min)</translation>
    </message>
</context>
<context>
    <name>Service.Action.Set.Startup.Mode</name>
    <message>
        <source>Failed to set service startup type</source>
        <translation>Nepodařilo se nastavit typ spouštění služby</translation>
    </message>
    <message>
        <source>Error: Failed to set service startup type due to the crashed sub process.</source>
        <translation>Chyba: Nepodařilo se nastavit typ spouštění služby kvůli zhavarovanému podprocesu.</translation>
    </message>
</context>
<context>
    <name>Service.Instance.Name.Dialog</name>
    <message>
        <source>Service instance name</source>
        <translation>Název instance služby</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Storno</translation>
    </message>
</context>
<context>
    <name>Service.Table.Context.Menu</name>
    <message>
        <source>Refresh</source>
        <translation>Načíst znovu</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Spustit</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Zastavit</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation>Restartovat</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automaticky</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ručně</translation>
    </message>
    <message>
        <source>Startup type</source>
        <translation>Typ spouštění</translation>
    </message>
</context>
<context>
    <name>Service.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Načtení</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktivita</translation>
    </message>
    <message>
        <source>Sub</source>
        <translation>Stav chodu</translation>
    </message>
    <message>
        <source>State</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Popis</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>Identif. procesu</translation>
    </message>
    <message>
        <source>Startup Type</source>
        <translation>Typ spouštění</translation>
    </message>
</context>
<context>
    <name>SystemProtectionSetting</name>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>(Modifiable)</source>
        <translation>(Lze změnit)</translation>
    </message>
    <message>
        <source>Range: %1-%2</source>
        <translation>Rozsah: %1-%2</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Context.Menu</name>
    <message>
        <source>Force end application</source>
        <translation>Vynutit ukončení aplikace</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Rozšířené</translation>
    </message>
    <message>
        <source>Compact</source>
        <translation>Kompaktní</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Zobrazení</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Search</name>
    <message>
        <source>Search</source>
        <translation>Hledat</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Switch</name>
    <message>
        <source>Processes</source>
        <translation>Procesy</translation>
    </message>
    <message>
        <source>Services</source>
        <translation>Služby</translation>
    </message>
</context>
</TS>
